@@ -214,4 +214,7 @@ class User:
         self.password = password
         self.log_status = log_status
         # 获取 token
+        # 对 js 传来的 None 进行处理
+        if token == "undefined":
+            token = None
         self.token = token or self._get_token()
